@@ -1,4 +1,4 @@
-package Pcore::API::Majestic v0.8.0;
+package Pcore::API::Majestic v0.9.0;
 
 use Pcore -dist, -class, -const, -result, -export => { CONST => [qw[$MAJESTIC_INDEX_FRESH $MAJESTIC_INDEX_HISTORIC]] };
 
@@ -86,6 +86,34 @@ sub get_backlink_data ( $self, $domain, $params, $cb ) {
     return;
 }
 
+# https://developer-support.majestic.com/api/commands/get-anchor-text.shtml
+sub get_anchor_text ( $self, $domain, $params, $cb ) {
+    my $url_params = {
+        cmd                  => 'GetAnchorText',
+        datasource           => 'fresh',
+        item                 => $domain,
+        Count                => 100,               # Number of results to be returned back. Max. 50_000
+        TextMode             => 0,
+        Mode                 => 0,
+        FilterAnchorText     => undef,
+        FilterAnchorTextMode => 0,
+        FilterRefDomain      => undef,
+        UsePrefixScan        => 0,
+        defined $params ? $params->%* : (),
+    };
+
+    $self->_request(
+        $url_params,
+        sub ($res) {
+            $cb->($res);
+
+            return;
+        }
+    );
+
+    return;
+}
+
 sub _request ( $self, $url_params, $cb ) {
     if ( $self->api_key ) {
         $url_params->{app_api_key} = $self->api_key;
